/**
 * Copyright (c) 2023, Furkan Mudanyali <fmudanyali@icloud.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <window/window.h>

Window::Window(Game* pGame) {
    this->game = pGame;
    if (SDL_Init(SDL_FLAGS) != 0) {
        throw SDL_GetError();
    }

    this->window = SDL_CreateWindow(WINDOW_TITLE, SDL_WINDOWPOS_CENTERED,
                                    SDL_WINDOWPOS_CENTERED, WINDOW_INITIAL_W,
                                    WINDOW_INITIAL_H, SDL_WINDOW_FLAGS);
}

Window::~Window() {
    SDL_DestroyWindow(this->window);
    SDL_Quit();
}

void Window::updateDimensions() {
    SDL_GL_GetDrawableSize(this->window, &this->width, &this->height);
}

int Window::getWidth() const {
    return this->width;
}

int Window::getHeight() const {
    return this->height;
}